# swagger-java-client

## Requirements

Building the API client library requires [Maven](https://maven.apache.org/) to be installed.

## Installation

To install the API client library to your local Maven repository, simply execute:

```shell
mvn install
```

To deploy it to a remote Maven repository instead, configure the settings of the repository and execute:

```shell
mvn deploy
```

Refer to the [official documentation](https://maven.apache.org/plugins/maven-deploy-plugin/usage.html) for more information.

### Maven users

Add this dependency to your project's POM:

```xml
<dependency>
    <groupId>io.swagger</groupId>
    <artifactId>swagger-java-client</artifactId>
    <version>1.0.0</version>
    <scope>compile</scope>
</dependency>
```

### Gradle users

Add this dependency to your project's build file:

```groovy
compile "io.swagger:swagger-java-client:1.0.0"
```

### Others

At first generate the JAR by executing:

    mvn package

Then manually install the following JARs:

* target/swagger-java-client-1.0.0.jar
* target/lib/*.jar

## Getting Started

Please follow the [installation](#installation) instruction and execute the following Java code:

```java

import io.swagger.client.*;
import io.swagger.client.auth.*;
import io.swagger.client.model.*;
import io.swagger.client.api.AdminSourcesApi;

import java.io.File;
import java.util.*;

public class AdminSourcesApiExample {

    public static void main(String[] args) {
        
        AdminSourcesApi apiInstance = new AdminSourcesApi();
        String adminsourceUid = "adminsourceUid_example"; // String | AdminSource UID
        String envelope = "envelope_example"; // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
        List<String> embed = Arrays.asList("embed_example"); // List<String> | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name)
        try {
            AdminSourcesEndpointType result = apiInstance.getAdminSourceByUID(adminsourceUid, envelope, embed);
            System.out.println(result);
        } catch (ApiException e) {
            System.err.println("Exception when calling AdminSourcesApi#getAdminSourceByUID");
            e.printStackTrace();
        }
    }
}

```

## Documentation for API Endpoints

All URIs are relative to *https://platform.its4land.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AdminSourcesApi* | [**getAdminSourceByUID**](docs/AdminSourcesApi.md#getAdminSourceByUID) | **GET** /adminsources/{adminsource_uid} | Returns a single Admin Source
*AdminSourcesApi* | [**getAdminSources**](docs/AdminSourcesApi.md#getAdminSources) | **GET** /adminsources | Returns a list of AdminSource document indizes
*AdminSourcesApi* | [**newAdminSource**](docs/AdminSourcesApi.md#newAdminSource) | **POST** /adminsources | Creates a new AdminSource
*AdminSourcesApi* | [**updateAdminSource**](docs/AdminSourcesApi.md#updateAdminSource) | **PATCH** /adminsources/{adminsource_uid} | Update an Admin Source
*BoundaryFaceStringApi* | [**getBoundaryFaceString**](docs/BoundaryFaceStringApi.md#getBoundaryFaceString) | **GET** /boundaryfacestring | Returns a list of boundary face strings in a GeoJSON structure.
*BoundaryFaceStringApi* | [**getBoundaryFaceStringByUID**](docs/BoundaryFaceStringApi.md#getBoundaryFaceStringByUID) | **GET** /boundaryfacestring/{boundaryfacestring_uid} | Returns a single boundary face string
*BoundaryFaceStringApi* | [**newBoundaryFaceString**](docs/BoundaryFaceStringApi.md#newBoundaryFaceString) | **POST** /boundaryfacestring | Create a new concept for a boundary face string
*BoundaryFaceStringApi* | [**putBoundaryFaceStringByUID**](docs/BoundaryFaceStringApi.md#putBoundaryFaceStringByUID) | **PUT** /boundaryfacestring/{boundaryfacestring_uid} | Replace an existing BoundaryFaceString by a newer version
*BoundaryFaceStringApi* | [**updateBoundaryFaceString**](docs/BoundaryFaceStringApi.md#updateBoundaryFaceString) | **PATCH** /boundaryfacestring/{boundaryfacestring_uid} | Updates a boundary face string
*ClassifierApi* | [**getClassifier**](docs/ClassifierApi.md#getClassifier) | **GET** /classifier | Returns a list of classifier
*ClassifierApi* | [**getClassifierByUID**](docs/ClassifierApi.md#getClassifierByUID) | **GET** /classifier/{classifier_id} | Returns a single classifier.
*ClassifierApi* | [**newClassifier**](docs/ClassifierApi.md#newClassifier) | **POST** /classifier | Create a new classifier
*ContentItemsApi* | [**getContentItem**](docs/ContentItemsApi.md#getContentItem) | **GET** /contentitems/{contentitem_id} | Returns a single content from the object storage.
*ContentItemsApi* | [**getContentItems**](docs/ContentItemsApi.md#getContentItems) | **GET** /contentitems | Returns a list of contentitems
*ContentItemsApi* | [**newContentItem**](docs/ContentItemsApi.md#newContentItem) | **POST** /contentitems | Create a new content in the object storage
*MetricMapFeaturesApi* | [**getMetricMapFeature**](docs/MetricMapFeaturesApi.md#getMetricMapFeature) | **GET** /metricmapfeature | Returns MetricMapFeature
*MetricMapFeaturesApi* | [**newMetricMapFeature**](docs/MetricMapFeaturesApi.md#newMetricMapFeature) | **POST** /metricmapfeature | Create a new metricMapFeature
*MetricMapFeaturesApi* | [**updateMetricMapFeature**](docs/MetricMapFeaturesApi.md#updateMetricMapFeature) | **PATCH** /metricmapfeature/{mmf_uid} | Updates a metric map feature
*MiscApi* | [**getDDILayers**](docs/MiscApi.md#getDDILayers) | **GET** /DDILayers | Return a list of registered DDI (WFS/WMS) Layer
*MiscApi* | [**getPuSConfig**](docs/MiscApi.md#getPuSConfig) | **GET** /PuSConfig | Returns a list of configuration parameters as Key Value
*MiscApi* | [**newDDILayers**](docs/MiscApi.md#newDDILayers) | **POST** /DDILayers | Register a new DDI (WFS/WMS) Layer
*ModelClassesApi* | [**getModelClasses**](docs/ModelClassesApi.md#getModelClasses) | **GET** /modelclasses | Returns ModelClasses
*ModelClassesApi* | [**getModelClassesByUID**](docs/ModelClassesApi.md#getModelClassesByUID) | **GET** /modelclasses/{modelclasses_uid} | Returns a single model class
*ModelClassesApi* | [**updateModelClasses**](docs/ModelClassesApi.md#updateModelClasses) | **PATCH** /modelclasses/{modelclasses_uid} | Updates some attributes of a ModelClass
*ModelsApi* | [**getModels**](docs/ModelsApi.md#getModels) | **GET** /models | Returns a list of models.
*ModelsApi* | [**getModelsByUID**](docs/ModelsApi.md#getModelsByUID) | **GET** /models/{model_uid} | Returns a single model
*ModelsApi* | [**getModelsClassesByModel**](docs/ModelsApi.md#getModelsClassesByModel) | **GET** /models/{model_uid}/modelclasses | Returns the model classes of the classifier.
*ModelsApi* | [**newModel**](docs/ModelsApi.md#newModel) | **POST** /models | Create a new model
*ModelsApi* | [**newModelClassUnderModel**](docs/ModelsApi.md#newModelClassUnderModel) | **POST** /models/{model_uid}/modelclasses | Create a new ModelClass under a model
*ModelsApi* | [**updateModels**](docs/ModelsApi.md#updateModels) | **PATCH** /models/{model_uid} | Updates some attributes of a model
*ProcessesApi* | [**createProcessLog**](docs/ProcessesApi.md#createProcessLog) | **POST** /processes/{process_uid}/log | Writes a single log entry
*ProcessesApi* | [**createProcesses**](docs/ProcessesApi.md#createProcesses) | **POST** /processes | Creates a new  processes
*ProcessesApi* | [**getProcessByUID**](docs/ProcessesApi.md#getProcessByUID) | **GET** /processes/{process_uid} | Returns metadata for a single process
*ProcessesApi* | [**getProcessLog**](docs/ProcessesApi.md#getProcessLog) | **GET** /processes/{process_uid}/log | Get the full log of a process
*ProcessesApi* | [**getProcesses**](docs/ProcessesApi.md#getProcesses) | **GET** /processes | Get a list of processes
*ProjectsApi* | [**addTagToProject**](docs/ProjectsApi.md#addTagToProject) | **POST** /projects/{project_uid}/Tags | Adds a tag to the project
*ProjectsApi* | [**delProjectByUID**](docs/ProjectsApi.md#delProjectByUID) | **DELETE** /projects/{project_uid} | Deletes a single e project by its UID
*ProjectsApi* | [**detachProjectModel**](docs/ProjectsApi.md#detachProjectModel) | **DELETE** /projects/{project_uid}/Models/{model_uid} | Removes a model from a project.
*ProjectsApi* | [**detachProjectSpatialSource**](docs/ProjectsApi.md#detachProjectSpatialSource) | **DELETE** /projects/{project_uid}/SpatialSources/{spatialsource_uid} | Removes a spatialsource from a project.
*ProjectsApi* | [**detachProjectTag**](docs/ProjectsApi.md#detachProjectTag) | **DELETE** /projects/{project_uid}/Tags/{tag} | Removes a tag from a project.
*ProjectsApi* | [**getConnectedObjectsByProjectUID**](docs/ProjectsApi.md#getConnectedObjectsByProjectUID) | **GET** /projects/{project_uid}/connectedObjects | Returns an array of connect objects
*ProjectsApi* | [**getModelsByProjectUID**](docs/ProjectsApi.md#getModelsByProjectUID) | **GET** /projects/{project_uid}/Models | Returns the models of a project
*ProjectsApi* | [**getProjectTagsByProjectUID**](docs/ProjectsApi.md#getProjectTagsByProjectUID) | **GET** /projects/{project_uid}/Tags | Returns the tags of a project.
*ProjectsApi* | [**getProjects**](docs/ProjectsApi.md#getProjects) | **GET** /projects | Get a GeoJSON structure containing a list of Projects.
*ProjectsApi* | [**getProjectsByUID**](docs/ProjectsApi.md#getProjectsByUID) | **GET** /projects/{project_uid} | Getting single Projects by its UID
*ProjectsApi* | [**getSpatialSourceByProjectUID**](docs/ProjectsApi.md#getSpatialSourceByProjectUID) | **GET** /projects/{project_uid}/SpatialSources | Returns the SpatialSources of a Project.
*ProjectsApi* | [**newModelUnderProject**](docs/ProjectsApi.md#newModelUnderProject) | **POST** /projects/{project_uid}/Models | Create a new model
*ProjectsApi* | [**newProject**](docs/ProjectsApi.md#newProject) | **POST** /projects | Create a new project
*ProjectsApi* | [**newSpatialSourceUnderProject**](docs/ProjectsApi.md#newSpatialSourceUnderProject) | **POST** /projects/{project_uid}/SpatialSources | Create a new SpatialSource
*ProjectsApi* | [**updateProjects**](docs/ProjectsApi.md#updateProjects) | **PATCH** /projects/{project_uid} | Update a project
*SpatialSourcesApi* | [**detachSpatialSourceAddDoc**](docs/SpatialSourcesApi.md#detachSpatialSourceAddDoc) | **DELETE** /spatialsource/{spatialsource_uid}/AdditionalDocument/{adddoc_uid} | Removes an additional document for a spatial source.
*SpatialSourcesApi* | [**getSpatialSourceAddDocs**](docs/SpatialSourcesApi.md#getSpatialSourceAddDocs) | **GET** /spatialsource/{spatialsource_uid}/AdditionalDocument | Returns the additional documents of a spatial source
*SpatialSourcesApi* | [**getSpatialSourceByUID**](docs/SpatialSourcesApi.md#getSpatialSourceByUID) | **GET** /spatialsource/{spatialsource_uid} | Returns a single SpatialSource
*SpatialSourcesApi* | [**getSpatialSourceSingleAddDoc**](docs/SpatialSourcesApi.md#getSpatialSourceSingleAddDoc) | **GET** /spatialsource/{spatialsource_uid}/AdditionalDocument/{adddoc_uid} | Returns the additional documents of a spatial source
*SpatialSourcesApi* | [**getSpatialSources**](docs/SpatialSourcesApi.md#getSpatialSources) | **GET** /spatialsources | Returns a list of SpatialSources
*SpatialSourcesApi* | [**newSpatialSource**](docs/SpatialSourcesApi.md#newSpatialSource) | **POST** /spatialsources | Create a new SpatialSource
*SpatialSourcesApi* | [**newSpatialSourceAddAddDoc**](docs/SpatialSourcesApi.md#newSpatialSourceAddAddDoc) | **POST** /spatialsource/{spatialsource_uid}/AdditionalDocument | Add a new additional document to a spatial source
*SpatialSourcesApi* | [**putSpatialSourceByUID**](docs/SpatialSourcesApi.md#putSpatialSourceByUID) | **PUT** /spatialsource/{spatialsource_uid} | Replace an existing SpatialSource by a newer version
*SpatialUnitsApi* | [**create2PpolygonSPUfromBFS**](docs/SpatialUnitsApi.md#create2PpolygonSPUfromBFS) | **POST** /spatialunits/create2Dpolygonspatialunit | Creates a spatial unit
*SpatialUnitsApi* | [**getSpatialUnitByUID**](docs/SpatialUnitsApi.md#getSpatialUnitByUID) | **GET** /spatialunits/qualitative/{spatialunit_uid} | Returns a single spatial unit
*SpatialUnitsApi* | [**getSpatialUnitConceptByUID**](docs/SpatialUnitsApi.md#getSpatialUnitConceptByUID) | **GET** /spatialunits/concepts/{concept_uid} | Returns a single spatial unit concept
*SpatialUnitsApi* | [**getSpatialUnits**](docs/SpatialUnitsApi.md#getSpatialUnits) | **GET** /spatialunits | Returns a list of SpatialUnits in a GeoJSON structure.
*SpatialUnitsApi* | [**getSpatialUnitsByUUID**](docs/SpatialUnitsApi.md#getSpatialUnitsByUUID) | **GET** /spatialunits/{spatialunit_uid} | Returns a list of SpatialUnits
*SpatialUnitsApi* | [**getSpatialUnitsConcepts**](docs/SpatialUnitsApi.md#getSpatialUnitsConcepts) | **GET** /spatialunits/concepts | Returns a list of spatial units concepts
*SpatialUnitsApi* | [**getSpatialUnitsQualitative**](docs/SpatialUnitsApi.md#getSpatialUnitsQualitative) | **GET** /spatialunits/qualitative | Returns a list of SpatialUnits
*SpatialUnitsApi* | [**newSpatialUnit**](docs/SpatialUnitsApi.md#newSpatialUnit) | **POST** /spatialunits | Create a new SpatialUnit
*SpatialUnitsApi* | [**newSpatialUnitConcept**](docs/SpatialUnitsApi.md#newSpatialUnitConcept) | **POST** /spatialunits/concepts | Create a new concept for a spatial unit
*SpatialUnitsApi* | [**newSpatialUnitQualitative**](docs/SpatialUnitsApi.md#newSpatialUnitQualitative) | **POST** /spatialunits/qualitative | Create a new SpatialUnit
*SpatialUnitsApi* | [**updateSpatialUnit**](docs/SpatialUnitsApi.md#updateSpatialUnit) | **PATCH** /spatialunits/{spatialunit_uid} | Update an spatial unit
*SpatialUnitsApi* | [**updateSpatialUnitConcept**](docs/SpatialUnitsApi.md#updateSpatialUnitConcept) | **PATCH** /spatialunits/concepts/{concept_uid} | Updates a new spatial unit concept
*SpatialUnitsApi* | [**updateSpatialUnitQualitative**](docs/SpatialUnitsApi.md#updateSpatialUnitQualitative) | **PATCH** /spatialunits/qualitative/{spatialunit_uid} | Updates a new SpatialUnit
*TagsApi* | [**getTagByName**](docs/TagsApi.md#getTagByName) | **GET** /tags/{tag_name} | Returns a single tag
*TagsApi* | [**getTags**](docs/TagsApi.md#getTags) | **GET** /tags | Get a list of tags
*TagsApi* | [**mergeTagByUID**](docs/TagsApi.md#mergeTagByUID) | **PATCH** /tags/{tag_uid}/merge | Merge tags
*TagsApi* | [**updateTagByName**](docs/TagsApi.md#updateTagByName) | **PATCH** /tags/{tag_name} | Updates a tag
*ToolsApi* | [**getTools**](docs/ToolsApi.md#getTools) | **GET** /tools | Get a list of tools
*TrainingSetsApi* | [**getTrainingSetByUID**](docs/TrainingSetsApi.md#getTrainingSetByUID) | **GET** /trainingsets/{trainingsets_uid} | Returns a single TrainingSet
*TrainingSetsApi* | [**getTrainingSets**](docs/TrainingSetsApi.md#getTrainingSets) | **GET** /trainingsets | Returns a list of TrainingSets
*TrainingSetsApi* | [**newTrainingSet**](docs/TrainingSetsApi.md#newTrainingSet) | **POST** /trainingsets | Create a new TrainingSet
*Wp5ValidationSetsApi* | [**getWP5ValidationSetByUID**](docs/Wp5ValidationSetsApi.md#getWP5ValidationSetByUID) | **GET** /WP5ValidationSets/{wp5validationset_uid} | Returns a single WP5ValidationSet
*Wp5ValidationSetsApi* | [**getWP5ValidationSets**](docs/Wp5ValidationSetsApi.md#getWP5ValidationSets) | **GET** /WP5ValidationSets | Returns a list of WP5ValidationSets
*Wp5ValidationSetsApi* | [**newWP5ValidationSets**](docs/Wp5ValidationSetsApi.md#newWP5ValidationSets) | **POST** /WP5ValidationSets | Create a new WP5ValidationSets


## Documentation for Models

 - [AdditionalDocumentsEndpointType](docs/AdditionalDocumentsEndpointType.md)
 - [AdditionalDocumentsPost](docs/AdditionalDocumentsPost.md)
 - [AdminSourcesEndpointType](docs/AdminSourcesEndpointType.md)
 - [AdminSourcesEndpointTypeSpatialUnits](docs/AdminSourcesEndpointTypeSpatialUnits.md)
 - [AdminSourcesPostRequest](docs/AdminSourcesPostRequest.md)
 - [BoundaryFaceStringEndpointType](docs/BoundaryFaceStringEndpointType.md)
 - [BoundaryFaceStringEndpointTypeFeatures](docs/BoundaryFaceStringEndpointTypeFeatures.md)
 - [BoundaryFaceStringEndpointTypeGeometry](docs/BoundaryFaceStringEndpointTypeGeometry.md)
 - [BoundaryFaceStringEndpointTypeProperties](docs/BoundaryFaceStringEndpointTypeProperties.md)
 - [BoundaryFaceStringEndpointTypePropertiesSpatialUnit](docs/BoundaryFaceStringEndpointTypePropertiesSpatialUnit.md)
 - [BoundaryFaceStringPostRequest](docs/BoundaryFaceStringPostRequest.md)
 - [BoundaryFaceStringPostRequestFeatures](docs/BoundaryFaceStringPostRequestFeatures.md)
 - [BoundaryFaceStringPostRequestProperties](docs/BoundaryFaceStringPostRequestProperties.md)
 - [ClassifierEndpointType](docs/ClassifierEndpointType.md)
 - [ClassifierPostRequest](docs/ClassifierPostRequest.md)
 - [ConnectedObjectsEndpointType](docs/ConnectedObjectsEndpointType.md)
 - [ConnectedObjectsEndpointTypeInner](docs/ConnectedObjectsEndpointTypeInner.md)
 - [ContentItemEndpointType](docs/ContentItemEndpointType.md)
 - [DDILayersEndpointType](docs/DDILayersEndpointType.md)
 - [DDILayersPostRequest](docs/DDILayersPostRequest.md)
 - [ImageSetsEndpointType](docs/ImageSetsEndpointType.md)
 - [ImageSetsEndpointTypeContentItems](docs/ImageSetsEndpointTypeContentItems.md)
 - [ImageSetsEndpointTypeMetadata](docs/ImageSetsEndpointTypeMetadata.md)
 - [LogEntryEndpointType](docs/LogEntryEndpointType.md)
 - [LogEntryPostRequest](docs/LogEntryPostRequest.md)
 - [MetricMapFeaturePostRequest](docs/MetricMapFeaturePostRequest.md)
 - [MetricMapFeaturePostRequestProperties](docs/MetricMapFeaturePostRequestProperties.md)
 - [MetricMapFeaturesEndpointType](docs/MetricMapFeaturesEndpointType.md)
 - [MetricMapFeaturesEndpointTypeFeatures](docs/MetricMapFeaturesEndpointTypeFeatures.md)
 - [MetricMapFeaturesEndpointTypeGeometry](docs/MetricMapFeaturesEndpointTypeGeometry.md)
 - [MetricMapFeaturesEndpointTypeProperties](docs/MetricMapFeaturesEndpointTypeProperties.md)
 - [ModelClassesEndpointType](docs/ModelClassesEndpointType.md)
 - [ModelClassesEndpointTypeModel](docs/ModelClassesEndpointTypeModel.md)
 - [ModelClassesPostRequest](docs/ModelClassesPostRequest.md)
 - [ModelsEndpointType](docs/ModelsEndpointType.md)
 - [ModelsEndpointTypeModelClasses](docs/ModelsEndpointTypeModelClasses.md)
 - [ModelsEndpointTypeProjects](docs/ModelsEndpointTypeProjects.md)
 - [ModelsPatchRequest](docs/ModelsPatchRequest.md)
 - [ModelsPostRequest](docs/ModelsPostRequest.md)
 - [ProcessEndpointType](docs/ProcessEndpointType.md)
 - [ProcessEndpointTypeProject](docs/ProcessEndpointTypeProject.md)
 - [ProcessEndpointTypeResults](docs/ProcessEndpointTypeResults.md)
 - [ProcessEndpointTypeTool](docs/ProcessEndpointTypeTool.md)
 - [ProcessEndpointTypeToolEntryPoint](docs/ProcessEndpointTypeToolEntryPoint.md)
 - [ProcessEndpointTypeToolEntryPointParameter](docs/ProcessEndpointTypeToolEntryPointParameter.md)
 - [ProcessPostRequest](docs/ProcessPostRequest.md)
 - [ProcessPostRequestProject](docs/ProcessPostRequestProject.md)
 - [ProcessPostRequestTool](docs/ProcessPostRequestTool.md)
 - [ProcessPostRequestToolEntryPoint](docs/ProcessPostRequestToolEntryPoint.md)
 - [ProjectsEndpointType](docs/ProjectsEndpointType.md)
 - [ProjectsEndpointType2](docs/ProjectsEndpointType2.md)
 - [ProjectsEndpointType2Features](docs/ProjectsEndpointType2Features.md)
 - [ProjectsEndpointType2Properties](docs/ProjectsEndpointType2Properties.md)
 - [ProjectsEndpointTypeCrs](docs/ProjectsEndpointTypeCrs.md)
 - [ProjectsEndpointTypeCrsProperties](docs/ProjectsEndpointTypeCrsProperties.md)
 - [ProjectsEndpointTypeFeatures](docs/ProjectsEndpointTypeFeatures.md)
 - [ProjectsEndpointTypeGeometry](docs/ProjectsEndpointTypeGeometry.md)
 - [ProjectsEndpointTypeProperties](docs/ProjectsEndpointTypeProperties.md)
 - [ProjectsEndpointTypePropertiesModels](docs/ProjectsEndpointTypePropertiesModels.md)
 - [ProjectsEndpointTypePropertiesSpatialSources](docs/ProjectsEndpointTypePropertiesSpatialSources.md)
 - [ProjectsPatchRequest](docs/ProjectsPatchRequest.md)
 - [ProjectsPostRequest](docs/ProjectsPostRequest.md)
 - [ProjectsPostRequestFeatures](docs/ProjectsPostRequestFeatures.md)
 - [ProjectsPostRequestProperties](docs/ProjectsPostRequestProperties.md)
 - [ProjectsPostRequestPropertiesSpatialSources](docs/ProjectsPostRequestPropertiesSpatialSources.md)
 - [PublishAndShareConfigEndpointType](docs/PublishAndShareConfigEndpointType.md)
 - [PublishAndShareConfigEndpointTypeInner](docs/PublishAndShareConfigEndpointTypeInner.md)
 - [RFC6902PatchRequest](docs/RFC6902PatchRequest.md)
 - [RFC6902PatchRequestOrg](docs/RFC6902PatchRequestOrg.md)
 - [RFC6902PatchRequestOrgInner](docs/RFC6902PatchRequestOrgInner.md)
 - [SiteEndpointType](docs/SiteEndpointType.md)
 - [SpatialSourcesEndpointType](docs/SpatialSourcesEndpointType.md)
 - [SpatialSourcesEndpointTypeAdditionalDocuments](docs/SpatialSourcesEndpointTypeAdditionalDocuments.md)
 - [SpatialSourcesPostRequest](docs/SpatialSourcesPostRequest.md)
 - [SpatialUnitBaseFeaturePostRequest](docs/SpatialUnitBaseFeaturePostRequest.md)
 - [SpatialUnitConceptEndpointType](docs/SpatialUnitConceptEndpointType.md)
 - [SpatialUnitConceptPostRequest](docs/SpatialUnitConceptPostRequest.md)
 - [SpatialUnitsFeatureEndpointType](docs/SpatialUnitsFeatureEndpointType.md)
 - [SpatialUnitsFeatureEndpointTypeFeatures](docs/SpatialUnitsFeatureEndpointTypeFeatures.md)
 - [SpatialUnitsFeatureEndpointTypeProperties](docs/SpatialUnitsFeatureEndpointTypeProperties.md)
 - [SpatialUnitsFeatureEndpointTypePropertiesAdminSource](docs/SpatialUnitsFeatureEndpointTypePropertiesAdminSource.md)
 - [SpatialUnitsFeatureEndpointTypePropertiesProjects](docs/SpatialUnitsFeatureEndpointTypePropertiesProjects.md)
 - [SpatialUnitsFeaturePostRequest](docs/SpatialUnitsFeaturePostRequest.md)
 - [SpatialUnitsFeaturePostRequestFeatures](docs/SpatialUnitsFeaturePostRequestFeatures.md)
 - [SpatialUnitsFeaturePostRequestProperties](docs/SpatialUnitsFeaturePostRequestProperties.md)
 - [TagsEndpointType](docs/TagsEndpointType.md)
 - [TagsEndpointTypeTaggedObjects](docs/TagsEndpointTypeTaggedObjects.md)
 - [TagsEndpointTypeTaggedObjectsSum](docs/TagsEndpointTypeTaggedObjectsSum.md)
 - [TagsListResponse](docs/TagsListResponse.md)
 - [TagsPostRequest](docs/TagsPostRequest.md)
 - [ToolsEndpointType](docs/ToolsEndpointType.md)
 - [ToolsEndpointTypeEntryPoints](docs/ToolsEndpointTypeEntryPoints.md)
 - [ToolsEndpointTypeImage](docs/ToolsEndpointTypeImage.md)
 - [TrainingSetsPostRequest](docs/TrainingSetsPostRequest.md)
 - [TrainingsSetEndpointType](docs/TrainingsSetEndpointType.md)
 - [TrainingsSetEndpointTypeModels](docs/TrainingsSetEndpointTypeModels.md)
 - [WP5ValidationSetsEndpointType](docs/WP5ValidationSetsEndpointType.md)
 - [WP5ValidationSetsPostRequest](docs/WP5ValidationSetsPostRequest.md)


## Documentation for Authorization

Authentication schemes defined for the API:
### api_key

- **Type**: API key
- **API key parameter name**: X-i4lAPIKEY
- **Location**: HTTP header


## Recommendation

It's recommended to create an instance of `ApiClient` per thread in a multithreaded environment to avoid any potential issues.

## Author

contact@its4land.com

