# ProjectsApi

All URIs are relative to *https://platform.its4land.com*

Method | HTTP request | Description
------------- | ------------- | -------------
[**addTagToProject**](ProjectsApi.md#addTagToProject) | **POST** /projects/{project_uid}/Tags | Adds a tag to the project
[**delProjectByUID**](ProjectsApi.md#delProjectByUID) | **DELETE** /projects/{project_uid} | Deletes a single e project by its UID
[**detachProjectModel**](ProjectsApi.md#detachProjectModel) | **DELETE** /projects/{project_uid}/Models/{model_uid} | Removes a model from a project.
[**detachProjectSpatialSource**](ProjectsApi.md#detachProjectSpatialSource) | **DELETE** /projects/{project_uid}/SpatialSources/{spatialsource_uid} | Removes a spatialsource from a project.
[**detachProjectTag**](ProjectsApi.md#detachProjectTag) | **DELETE** /projects/{project_uid}/Tags/{tag} | Removes a tag from a project.
[**getConnectedObjectsByProjectUID**](ProjectsApi.md#getConnectedObjectsByProjectUID) | **GET** /projects/{project_uid}/connectedObjects | Returns an array of connect objects
[**getModelsByProjectUID**](ProjectsApi.md#getModelsByProjectUID) | **GET** /projects/{project_uid}/Models | Returns the models of a project
[**getProjectTagsByProjectUID**](ProjectsApi.md#getProjectTagsByProjectUID) | **GET** /projects/{project_uid}/Tags | Returns the tags of a project.
[**getProjects**](ProjectsApi.md#getProjects) | **GET** /projects | Get a GeoJSON structure containing a list of Projects.
[**getProjectsByUID**](ProjectsApi.md#getProjectsByUID) | **GET** /projects/{project_uid} | Getting single Projects by its UID
[**getSpatialSourceByProjectUID**](ProjectsApi.md#getSpatialSourceByProjectUID) | **GET** /projects/{project_uid}/SpatialSources | Returns the SpatialSources of a Project.
[**newModelUnderProject**](ProjectsApi.md#newModelUnderProject) | **POST** /projects/{project_uid}/Models | Create a new model
[**newProject**](ProjectsApi.md#newProject) | **POST** /projects | Create a new project
[**newSpatialSourceUnderProject**](ProjectsApi.md#newSpatialSourceUnderProject) | **POST** /projects/{project_uid}/SpatialSources | Create a new SpatialSource
[**updateProjects**](ProjectsApi.md#updateProjects) | **PATCH** /projects/{project_uid} | Update a project


<a name="addTagToProject"></a>
# **addTagToProject**
> ProjectsEndpointType addTagToProject(projectUid, newtag, envelope, embed, i4lProcessUid)

Adds a tag to the project

Creates a new tag and attach it to the project. If the tag already exist, the existing tag will be attached to the project.

### Example
```java
// Import classes:
//import io.swagger.client.ApiException;
//import io.swagger.client.api.ProjectsApi;


ProjectsApi apiInstance = new ProjectsApi();
String projectUid = "projectUid_example"; // String | Project UID
TagsPostRequest newtag = new TagsPostRequest(); // TagsPostRequest | New Tag data
String envelope = "envelope_example"; // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
List<String> embed = Arrays.asList("embed_example"); // List<String> | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name)
String i4lProcessUid = "i4lProcessUid_example"; // String | Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process.
try {
    ProjectsEndpointType result = apiInstance.addTagToProject(projectUid, newtag, envelope, embed, i4lProcessUid);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling ProjectsApi#addTagToProject");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **String**| Project UID |
 **newtag** | [**TagsPostRequest**](TagsPostRequest.md)| New Tag data |
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] [enum: yes, no]
 **embed** | [**List&lt;String&gt;**](String.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional]
 **i4lProcessUid** | **String**| Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. | [optional]

### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="delProjectByUID"></a>
# **delProjectByUID**
> ProjectsEndpointType delProjectByUID(projectUid, envelope, embed, i4lProcessUid)

Deletes a single e project by its UID

A single project is deleted. This endpoint deletes the project itself and the connected to subordered data like SpatialSources, etc. The subordered data itself are not deleted

### Example
```java
// Import classes:
//import io.swagger.client.ApiException;
//import io.swagger.client.api.ProjectsApi;


ProjectsApi apiInstance = new ProjectsApi();
String projectUid = "projectUid_example"; // String | UID of the project
String envelope = "envelope_example"; // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
List<String> embed = Arrays.asList("embed_example"); // List<String> | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name)
String i4lProcessUid = "i4lProcessUid_example"; // String | Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process.
try {
    ProjectsEndpointType result = apiInstance.delProjectByUID(projectUid, envelope, embed, i4lProcessUid);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling ProjectsApi#delProjectByUID");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **String**| UID of the project |
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] [enum: yes, no]
 **embed** | [**List&lt;String&gt;**](String.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional]
 **i4lProcessUid** | **String**| Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. | [optional]

### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="detachProjectModel"></a>
# **detachProjectModel**
> ProjectsEndpointType detachProjectModel(projectUid, modelUid, envelope, forceDelete)

Removes a model from a project.

Removes a model from a project. By default only the link between model and project is removed.

### Example
```java
// Import classes:
//import io.swagger.client.ApiException;
//import io.swagger.client.api.ProjectsApi;


ProjectsApi apiInstance = new ProjectsApi();
String projectUid = "projectUid_example"; // String | Project UID
String modelUid = "modelUid_example"; // String | Model UID
String envelope = "envelope_example"; // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
String forceDelete = "forceDelete_example"; // String | Deletes the model resource. ********* What's about subordinate resources? *********
try {
    ProjectsEndpointType result = apiInstance.detachProjectModel(projectUid, modelUid, envelope, forceDelete);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling ProjectsApi#detachProjectModel");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **String**| Project UID |
 **modelUid** | **String**| Model UID |
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] [enum: yes, no]
 **forceDelete** | **String**| Deletes the model resource. ********* What&#39;s about subordinate resources? ********* | [optional]

### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="detachProjectSpatialSource"></a>
# **detachProjectSpatialSource**
> ProjectsEndpointType detachProjectSpatialSource(projectUid, spatialsourceUid, forceDelete)

Removes a spatialsource from a project.

Removes a spatial from a project. By default only the link between spatialsource and project is removed.

### Example
```java
// Import classes:
//import io.swagger.client.ApiException;
//import io.swagger.client.api.ProjectsApi;


ProjectsApi apiInstance = new ProjectsApi();
String projectUid = "projectUid_example"; // String | Project UID
String spatialsourceUid = "spatialsourceUid_example"; // String | SpatialSource UID
String forceDelete = "forceDelete_example"; // String | Deletes the spatialsource resource. ********* What's about subordinate resources? *********
try {
    ProjectsEndpointType result = apiInstance.detachProjectSpatialSource(projectUid, spatialsourceUid, forceDelete);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling ProjectsApi#detachProjectSpatialSource");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **String**| Project UID |
 **spatialsourceUid** | **String**| SpatialSource UID |
 **forceDelete** | **String**| Deletes the spatialsource resource. ********* What&#39;s about subordinate resources? ********* | [optional]

### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="detachProjectTag"></a>
# **detachProjectTag**
> ProjectsEndpointType detachProjectTag(projectUid, tag, envelope, forceDelete)

Removes a tag from a project.

Removes a tag from a project. By default only the link between tag and project is removed.

### Example
```java
// Import classes:
//import io.swagger.client.ApiException;
//import io.swagger.client.api.ProjectsApi;


ProjectsApi apiInstance = new ProjectsApi();
String projectUid = "projectUid_example"; // String | Project UID
String tag = "tag_example"; // String | tag value
String envelope = "envelope_example"; // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
String forceDelete = "forceDelete_example"; // String | Deletes the tag resource. ********* Only possible, when tag is not attached to any other resource. *********
try {
    ProjectsEndpointType result = apiInstance.detachProjectTag(projectUid, tag, envelope, forceDelete);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling ProjectsApi#detachProjectTag");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **String**| Project UID |
 **tag** | **String**| tag value |
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] [enum: yes, no]
 **forceDelete** | **String**| Deletes the tag resource. ********* Only possible, when tag is not attached to any other resource. ********* | [optional]

### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getConnectedObjectsByProjectUID"></a>
# **getConnectedObjectsByProjectUID**
> ConnectedObjectsEndpointType getConnectedObjectsByProjectUID(projectUid, envelope, page, sort, fields, embed)

Returns an array of connect objects

Returns an array of connect objects of a project. For each connected object the endpoint returns the type, name and uuid

### Example
```java
// Import classes:
//import io.swagger.client.ApiException;
//import io.swagger.client.api.ProjectsApi;


ProjectsApi apiInstance = new ProjectsApi();
String projectUid = "projectUid_example"; // String | Project UID
String envelope = "envelope_example"; // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
Integer page = 56; // Integer | Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default.
String sort = "sort_example"; // String | The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by.
List<String> fields = Arrays.asList("fields_example"); // List<String> | Comma separated list of field names
List<String> embed = Arrays.asList("embed_example"); // List<String> | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name)
try {
    ConnectedObjectsEndpointType result = apiInstance.getConnectedObjectsByProjectUID(projectUid, envelope, page, sort, fields, embed);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling ProjectsApi#getConnectedObjectsByProjectUID");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **String**| Project UID |
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] [enum: yes, no]
 **page** | **Integer**| Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default. | [optional]
 **sort** | **String**| The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by. | [optional]
 **fields** | [**List&lt;String&gt;**](String.md)| Comma separated list of field names | [optional]
 **embed** | [**List&lt;String&gt;**](String.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional]

### Return type

[**ConnectedObjectsEndpointType**](ConnectedObjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getModelsByProjectUID"></a>
# **getModelsByProjectUID**
> List&lt;ModelsEndpointType&gt; getModelsByProjectUID(projectUid, envelope, page, sort, fields, embed)

Returns the models of a project

Returns the models of a project

### Example
```java
// Import classes:
//import io.swagger.client.ApiException;
//import io.swagger.client.api.ProjectsApi;


ProjectsApi apiInstance = new ProjectsApi();
String projectUid = "projectUid_example"; // String | Project UID
String envelope = "envelope_example"; // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
Integer page = 56; // Integer | Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default.
String sort = "sort_example"; // String | The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by.
List<String> fields = Arrays.asList("fields_example"); // List<String> | Comma separated list of field names
List<String> embed = Arrays.asList("embed_example"); // List<String> | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name)
try {
    List<ModelsEndpointType> result = apiInstance.getModelsByProjectUID(projectUid, envelope, page, sort, fields, embed);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling ProjectsApi#getModelsByProjectUID");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **String**| Project UID |
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] [enum: yes, no]
 **page** | **Integer**| Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default. | [optional]
 **sort** | **String**| The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by. | [optional]
 **fields** | [**List&lt;String&gt;**](String.md)| Comma separated list of field names | [optional]
 **embed** | [**List&lt;String&gt;**](String.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional]

### Return type

[**List&lt;ModelsEndpointType&gt;**](ModelsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getProjectTagsByProjectUID"></a>
# **getProjectTagsByProjectUID**
> TagsListResponse getProjectTagsByProjectUID(projectUid, envelope)

Returns the tags of a project.

Is this method really necessary? Returns the tags of a project.

### Example
```java
// Import classes:
//import io.swagger.client.ApiException;
//import io.swagger.client.api.ProjectsApi;


ProjectsApi apiInstance = new ProjectsApi();
String projectUid = "projectUid_example"; // String | Project UID
String envelope = "envelope_example"; // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
try {
    TagsListResponse result = apiInstance.getProjectTagsByProjectUID(projectUid, envelope);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling ProjectsApi#getProjectTagsByProjectUID");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **String**| Project UID |
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] [enum: yes, no]

### Return type

[**TagsListResponse**](TagsListResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getProjects"></a>
# **getProjects**
> ProjectsEndpointType getProjects(envelope, uid, name, aoi, tags, page, sort, fields, embed)

Get a GeoJSON structure containing a list of Projects.

Get a GeoJSON structure containing a list of Projects. A single project is modeled as a GeoJSON feature.

### Example
```java
// Import classes:
//import io.swagger.client.ApiException;
//import io.swagger.client.api.ProjectsApi;


ProjectsApi apiInstance = new ProjectsApi();
String envelope = "envelope_example"; // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
List<String> uid = Arrays.asList("uid_example"); // List<String> | Comma separated list of UID
List<String> name = Arrays.asList("name_example"); // List<String> | Comma separated list of names
String aoi = "aoi_example"; // String | Polygon. The polygon is encoded a comma separated list of coordinates. X1, Y1, X2, Y2, ..., Xn, Yn, X1, Y1
List<String> tags = Arrays.asList("tags_example"); // List<String> | Comma separated list of tags
Integer page = 56; // Integer | Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default.
String sort = "sort_example"; // String | The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by.
List<String> fields = Arrays.asList("fields_example"); // List<String> | Comma separated list of field names
List<String> embed = Arrays.asList("embed_example"); // List<String> | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name)
try {
    ProjectsEndpointType result = apiInstance.getProjects(envelope, uid, name, aoi, tags, page, sort, fields, embed);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling ProjectsApi#getProjects");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] [enum: yes, no]
 **uid** | [**List&lt;String&gt;**](String.md)| Comma separated list of UID | [optional]
 **name** | [**List&lt;String&gt;**](String.md)| Comma separated list of names | [optional]
 **aoi** | **String**| Polygon. The polygon is encoded a comma separated list of coordinates. X1, Y1, X2, Y2, ..., Xn, Yn, X1, Y1 | [optional]
 **tags** | [**List&lt;String&gt;**](String.md)| Comma separated list of tags | [optional]
 **page** | **Integer**| Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default. | [optional]
 **sort** | **String**| The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by. | [optional]
 **fields** | [**List&lt;String&gt;**](String.md)| Comma separated list of field names | [optional]
 **embed** | [**List&lt;String&gt;**](String.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional]

### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getProjectsByUID"></a>
# **getProjectsByUID**
> ProjectsEndpointType getProjectsByUID(projectUid, envelope, embed)

Getting single Projects by its UID

Getting single Projects by its UID. The project is modeled as a feature in a GeoJSON structure.

### Example
```java
// Import classes:
//import io.swagger.client.ApiException;
//import io.swagger.client.api.ProjectsApi;


ProjectsApi apiInstance = new ProjectsApi();
String projectUid = "projectUid_example"; // String | UID of the project
String envelope = "envelope_example"; // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
List<String> embed = Arrays.asList("embed_example"); // List<String> | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name)
try {
    ProjectsEndpointType result = apiInstance.getProjectsByUID(projectUid, envelope, embed);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling ProjectsApi#getProjectsByUID");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **String**| UID of the project |
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] [enum: yes, no]
 **embed** | [**List&lt;String&gt;**](String.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional]

### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getSpatialSourceByProjectUID"></a>
# **getSpatialSourceByProjectUID**
> List&lt;SpatialSourcesEndpointType&gt; getSpatialSourceByProjectUID(projectUid, envelope, page, sort, fields, embed)

Returns the SpatialSources of a Project.

Returns the SpatialSources of a Project.

### Example
```java
// Import classes:
//import io.swagger.client.ApiException;
//import io.swagger.client.api.ProjectsApi;


ProjectsApi apiInstance = new ProjectsApi();
String projectUid = "projectUid_example"; // String | Project UID
String envelope = "envelope_example"; // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
Integer page = 56; // Integer | Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default.
String sort = "sort_example"; // String | The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by.
List<String> fields = Arrays.asList("fields_example"); // List<String> | Comma separated list of field names
List<String> embed = Arrays.asList("embed_example"); // List<String> | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name)
try {
    List<SpatialSourcesEndpointType> result = apiInstance.getSpatialSourceByProjectUID(projectUid, envelope, page, sort, fields, embed);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling ProjectsApi#getSpatialSourceByProjectUID");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **String**| Project UID |
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] [enum: yes, no]
 **page** | **Integer**| Requests for collections can return between 0 and N results, controlled using the per_page and page query parameters. All endpoints are limited to 10 results by default. | [optional]
 **sort** | **String**| The sorting is initiated by the sort query parameter and a list of comma separated list of fields to sort by. | [optional]
 **fields** | [**List&lt;String&gt;**](String.md)| Comma separated list of field names | [optional]
 **embed** | [**List&lt;String&gt;**](String.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional]

### Return type

[**List&lt;SpatialSourcesEndpointType&gt;**](SpatialSourcesEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="newModelUnderProject"></a>
# **newModelUnderProject**
> ProjectsEndpointType newModelUnderProject(projectUid, newmodel, envelope, embed, i4lProcessUid)

Create a new model

Create a new model.  To add a new Model , the content of Models  must be stored in advanced via the ContentItem endpoint

### Example
```java
// Import classes:
//import io.swagger.client.ApiException;
//import io.swagger.client.api.ProjectsApi;


ProjectsApi apiInstance = new ProjectsApi();
String projectUid = "projectUid_example"; // String | Project UID
ModelsPostRequest newmodel = new ModelsPostRequest(); // ModelsPostRequest | New model data
String envelope = "envelope_example"; // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
List<String> embed = Arrays.asList("embed_example"); // List<String> | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name)
String i4lProcessUid = "i4lProcessUid_example"; // String | Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process.
try {
    ProjectsEndpointType result = apiInstance.newModelUnderProject(projectUid, newmodel, envelope, embed, i4lProcessUid);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling ProjectsApi#newModelUnderProject");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **String**| Project UID |
 **newmodel** | [**ModelsPostRequest**](ModelsPostRequest.md)| New model data |
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] [enum: yes, no]
 **embed** | [**List&lt;String&gt;**](String.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional]
 **i4lProcessUid** | **String**| Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. | [optional]

### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="newProject"></a>
# **newProject**
> ProjectsEndpointType newProject(newproject, envelope, embed, i4lProcessUid)

Create a new project

Create a new project. The new project is modeled as a feature in a GeoJSON structure. Currently only one project feature is allowed.

### Example
```java
// Import classes:
//import io.swagger.client.ApiException;
//import io.swagger.client.api.ProjectsApi;


ProjectsApi apiInstance = new ProjectsApi();
ProjectsPostRequest newproject = new ProjectsPostRequest(); // ProjectsPostRequest | New project data
String envelope = "envelope_example"; // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
List<String> embed = Arrays.asList("embed_example"); // List<String> | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name)
String i4lProcessUid = "i4lProcessUid_example"; // String | Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process.
try {
    ProjectsEndpointType result = apiInstance.newProject(newproject, envelope, embed, i4lProcessUid);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling ProjectsApi#newProject");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **newproject** | [**ProjectsPostRequest**](ProjectsPostRequest.md)| New project data |
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] [enum: yes, no]
 **embed** | [**List&lt;String&gt;**](String.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional]
 **i4lProcessUid** | **String**| Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. | [optional]

### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="newSpatialSourceUnderProject"></a>
# **newSpatialSourceUnderProject**
> ProjectsEndpointType newSpatialSourceUnderProject(projectUid, newspatialsource, envelope, embed, i4lProcessUid)

Create a new SpatialSource

Create a new SpatialSource. To add a new SpatialSource , the content of SpatialSource  must be stored in advanced via the ContentItem endpoint

### Example
```java
// Import classes:
//import io.swagger.client.ApiException;
//import io.swagger.client.api.ProjectsApi;


ProjectsApi apiInstance = new ProjectsApi();
String projectUid = "projectUid_example"; // String | Project UID
SpatialSourcesPostRequest newspatialsource = new SpatialSourcesPostRequest(); // SpatialSourcesPostRequest | New SpatialSource data
String envelope = "envelope_example"; // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
List<String> embed = Arrays.asList("embed_example"); // List<String> | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name)
String i4lProcessUid = "i4lProcessUid_example"; // String | Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process.
try {
    ProjectsEndpointType result = apiInstance.newSpatialSourceUnderProject(projectUid, newspatialsource, envelope, embed, i4lProcessUid);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling ProjectsApi#newSpatialSourceUnderProject");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **String**| Project UID |
 **newspatialsource** | [**SpatialSourcesPostRequest**](SpatialSourcesPostRequest.md)| New SpatialSource data |
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] [enum: yes, no]
 **embed** | [**List&lt;String&gt;**](String.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional]
 **i4lProcessUid** | **String**| Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. | [optional]

### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="updateProjects"></a>
# **updateProjects**
> ProjectsEndpointType updateProjects(projectUid, patchproject, envelope, embed, i4lProcessUid)

Update a project

Updates some attributes of a project.

### Example
```java
// Import classes:
//import io.swagger.client.ApiException;
//import io.swagger.client.api.ProjectsApi;


ProjectsApi apiInstance = new ProjectsApi();
String projectUid = "projectUid_example"; // String | Project UID to be patched
RFC6902PatchRequest patchproject = new RFC6902PatchRequest(); // RFC6902PatchRequest | Update data
String envelope = "envelope_example"; // String | The endpoint can package everything (header, status code) neatly into the response body. Include envelope=true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body.
List<String> embed = Arrays.asList("embed_example"); // List<String> | Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name)
String i4lProcessUid = "i4lProcessUid_example"; // String | Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process.
try {
    ProjectsEndpointType result = apiInstance.updateProjects(projectUid, patchproject, envelope, embed, i4lProcessUid);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling ProjectsApi#updateProjects");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **projectUid** | **String**| Project UID to be patched |
 **patchproject** | [**RFC6902PatchRequest**](RFC6902PatchRequest.md)| Update data |
 **envelope** | **String**| The endpoint can package everything (header, status code) neatly into the response body. Include envelope&#x3D;true as a request parameter. The API will always return a 200 HTTP status code. The real status, headers and response will be within the body. | [optional] [enum: yes, no]
 **embed** | [**List&lt;String&gt;**](String.md)| Embedding is triggered by passing in an embed query parameter, which takes a comma separated list of endpoint types. Single fields can be selected a dot-notation (endpoint-type.property-name) | [optional]
 **i4lProcessUid** | **String**| Process UID. This parameter can be used by an its4land tool running inside the runtime environment to pass the process uid to the endpoint. With this information the endpoint can associate the newly created or updated resource with the process. | [optional]

### Return type

[**ProjectsEndpointType**](ProjectsEndpointType.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

